lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:   Tue, 12 Nov 2019 09:11:53 +0100
From:   Ingo Molnar <mingo@...nel.org>
To:     Thomas Gleixner <tglx@...utronix.de>
Cc:     LKML <linux-kernel@...r.kernel.org>, x86@...nel.org,
        Linus Torvalds <torvalds@...uxfoundation.org>,
        Andy Lutomirski <luto@...nel.org>,
        Stephen Hemminger <stephen@...workplumber.org>,
        Willy Tarreau <w@....eu>, Juergen Gross <jgross@...e.com>,
        Sean Christopherson <sean.j.christopherson@...el.com>,
        "H. Peter Anvin" <hpa@...or.com>
Subject: [PATCH] x86/iopl: Clear up the role of the two bitmap copying fields


Here's another one, which makes the pointer-caching logic a bit clearer 
IMO:

Firstly, it lines up the two related fields in the namespace:

   x86_io_bitmap.last_bitmap        =>   bitmap_copied_ptr
   x86_io_bitmap.last_sequence      =>   bitmap_copied_seq

It also constifies the pointer to better signal that it should never 
actually be used for anything but comparison

I think the 'bitmap_copied_' ptr/seq pairing makes it more obvious, and 
removing the 'last' language makes it a tiny bit clearer that this bitmap 
is special because we copied its contents into the TSS.

This makes code like this a tiny bit easier to read IMHO:

+                       if (tss->io_bitmap.bitmap_copied_ptr != iobm ||
+                           tss->io_bitmap.bitmap_copied_seq != iobm->sequence)

I marked it RFC because you might not agree. :-)

Only build tested.

Thanks,

	Ingo

---
 arch/x86/include/asm/processor.h | 10 +++++-----
 arch/x86/kernel/cpu/common.c     |  2 +-
 arch/x86/kernel/process.c        |  8 ++++----
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/arch/x86/kernel/cpu/common.c b/arch/x86/kernel/cpu/common.c
index a35a557429e7..5a74c5b11b1c 100644
--- a/arch/x86/kernel/cpu/common.c
+++ b/arch/x86/kernel/cpu/common.c
@@ -1861,7 +1861,7 @@ void cpu_init(void)
 	/* Initialize the TSS. */
 	tss_setup_ist(tss);
 	tss->x86_tss.io_bitmap_base = IO_BITMAP_OFFSET_INVALID;
-	tss->io_bitmap.last_bitmap = NULL;
+	tss->io_bitmap.bitmap_copied_ptr = NULL;
 	tss->io_bitmap.bytes_max = 0;
 	memset(tss->io_bitmap.map_bytes, 0xff, sizeof(tss->io_bitmap.map_bytes));
 	set_tss_desc(cpu, &get_cpu_entry_area(cpu)->tss.x86_tss);
diff --git a/arch/x86/kernel/process.c b/arch/x86/kernel/process.c
index c4e76a540b51..ecf97855ed68 100644
--- a/arch/x86/kernel/process.c
+++ b/arch/x86/kernel/process.c
@@ -358,8 +358,8 @@ static void tss_copy_io_bitmap(struct tss_struct *tss, struct io_bitmap *iobm)
 	 * and a pointer to the bitmap itself.
 	 */
 	tss->io_bitmap.bytes_max = iobm->bytes_max;
-	tss->io_bitmap.last_sequence = iobm->sequence;
-	tss->io_bitmap.last_bitmap = iobm;
+	tss->io_bitmap.bitmap_copied_seq = iobm->sequence;
+	tss->io_bitmap.bitmap_copied_ptr = iobm;
 }
 
 /**
@@ -388,8 +388,8 @@ void tss_update_io_bitmap(void)
 			 * sequence number differs. The update time is
 			 * accounted to the incoming task.
 			 */
-			if (tss->io_bitmap.last_bitmap != iobm ||
-			    tss->io_bitmap.last_sequence != iobm->sequence)
+			if (tss->io_bitmap.bitmap_copied_ptr != iobm ||
+			    tss->io_bitmap.bitmap_copied_seq != iobm->sequence)
 				tss_copy_io_bitmap(tss, iobm);
 
 			/* Enable the bitmap */

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ
diff --git a/arch/x86/include/asm/processor.h b/arch/x86/include/asm/processor.h
index d1f2c1eb14e9..b45ff7c1419f 100644
--- a/arch/x86/include/asm/processor.h
+++ b/arch/x86/include/asm/processor.h
@@ -367,12 +367,12 @@ struct entry_stack_page {
 struct x86_io_bitmap
 {
 	/*
 	 * The bitmap pointer and the sequence number of the last active
 	 * bitmap. last_bitmap cannot be dereferenced. It's solely for
 	 * comparison.
 	 */
-	struct io_bitmap	*last_bitmap;
-	u64			last_sequence;
+	const struct io_bitmap	*bitmap_copied_ptr;
+	u64			bitmap_copied_seq;
 
 	/*
 	 * Store the dirty size of the last io bitmap offender. The next
@@ -367,12 +367,12 @@ struct entry_stack_page {
 {
 	/*
-	 * The bitmap pointer and the sequence number of the last active
-	 * bitmap. last_bitmap cannot be dereferenced. It's solely for
-	 * comparison.
+	 * The bitmap pointer and the sequence number of the last copied
+	 * bitmap. bitmap_copied_ptr must not be dereferenced, it's solely
+	 * for comparison.
 	 */